/* Generated automatically. */
static const char configuration_arguments[] = "/home/arnd/git/gcc/configure --host=aarch64-linux-gnu --build=x86_64-linux-gnu --target=powerpc64-linux --enable-targets=all --prefix=/opt/crosstool/canadian-arm/gcc-7.3.0-nolibc/powerpc64-linux --enable-languages=c --without-headers --disable-bootstrap --disable-nls --disable-threads --disable-shared --disable-libmudflap --disable-libssp --disable-libgomp --disable-decimal-float --disable-libquadmath --disable-libatomic --disable-libcc1 --disable-libmpx --enable-checking=release : (reconfigured) /home/arnd/git/gcc/configure --host=aarch64-linux-gnu --build=x86_64-linux-gnu --target=powerpc64-linux --enable-targets=all --prefix=/opt/crosstool/canadian-arm/gcc-7.3.0-nolibc/powerpc64-linux --enable-languages=c --without-headers --disable-bootstrap --disable-nls --disable-threads --disable-shared --disable-libmudflap --disable-libssp --disable-libgomp --disable-decimal-float --disable-libquadmath --disable-libatomic --disable-libcc1 --disable-libmpx --enable-checking=release";
static const char thread_model[] = "single";

static const struct {
  const char *name, *value;
} configure_default_options[] = { { NULL, NULL} };
